@@ -9,7 +9,7 @@ from multiclass_model.config.core import config
 
 class InvoiceDataSchema(BaseModel):
     Inv_Id: Optional[int]
-    Vendor_Code: Optional[int]
+    Vendor_Code: Optional[str]
     GL_Code: Optional[str]
     Inv_Amt:Optional[float]
     Item_Description: Optional[str]
